Learn R Programming

RSNNS (version 0.4-4)

SnnsRObject$getUnitsByName: Find all units whose name begins with a given prefix.

Description

Find all units whose name begins with a given prefix.

Usage

## S3 method for class 'SnnsR':
getUnitsByName(prefix)

Arguments

prefix
a prefix that the names of the units to find have.

Value

  • a vector with integer numbers identifying the units.