Learn R Programming

RSNNS (version 0.3-1)

SnnsRObject$whereAreResults: Get a list of output units of a net.

Description

Get a list of output units of a net.

Usage

## S3 method for class 'SnnsR':
whereAreResults(outputMethod="output")

Arguments

outputMethod
a string defining the output method of the net.

Value

  • a list of numbers identifying the units

Details

Depending on the network architecture, output is present in hidden units, in output units, etc. In some network types, the output units have a certain name prefix in SNNS. This function finds the output units according to certain network types. Possible types (= values for outputMethod) are: "art1", "art2", "assoz", "som", "output". If the given outputMethod is unknown, the function defaults to "output".