Learn R Programming

RSNNS (version 0.3-1)

art1: Create and train an art1 network.

Description

Create and train an art1 network.

Usage

art1(x, ...)
## S3 method for class 'default':
art1(x, dimX, dimY, nClusters=nrow(x), maxit=100, initFunc="ART1_Weights",
    initFuncParams=c(1, 1), learnFunc="ART1", learnFuncParams=c(0.9, 0,
    0), updateFunc="ART1_Stable", updateFuncParams=c(0),
    shufflePatterns=TRUE, ...)

Arguments

x
a matrix with training inputs for the network
dimX
x dimension of inputs and outputs
dimY
y dimension of inputs and outputs
nClusters
controls the number of clusters assumed to be present
maxit
maximum of iterations to learn
initFunc
the initialization function to use
initFuncParams
the parameters for the initialization function
learnFunc
the learning function to use
learnFuncParams
the parameters for the learning function
updateFunc
the update function to use
updateFuncParams
the parameters for the update function
shufflePatterns
should the patterns be shuffled?
...
additional function parameters (currently not used)

Value

  • art1.default: an rsnns object. The fitted.values member of the object contains a list of two-dimensional activation patterns.

Details

art1: Adaptive resonance theory (art) networks are association networks. I.e. they perform clustering by finding a prototype to the given input. So, input and output are the same type of data. Art1 is for binary inputs only, if you have real-valued input, use art2 instead. In its current implementation, the network has two-dimensional input (and output). The matrix x contains all (one dimensional) input patterns. Internally, every one of these patterns is converted to a two-dimensional pattern using parameters dimX and dimY. The parameter nClusters controls the amount of clusters that are assumed to be present in the input patterns. A detailed description of the theory is available from the SNNS decumentation.

See Also

art2

Examples

Run this code
demo(art1_letters)
demo(art1_lettersSnnsR)

Run the code above in your browser using DataLab