Learn R Programming

RSNNS (version 0.3-1)

art2: Create and train an art2 network.

Description

Create and train an art2 network.

Usage

art2(x, ...)
## S3 method for class 'default':
art2(x, f2Units=5, maxit=100, initFunc="ART2_Weights", initFuncParams=c(0.9,
    2), learnFunc="ART2", learnFuncParams=c(0.98, 10, 10, 0.1, 0),
    updateFunc="ART2_Stable", updateFuncParams=c(0.98, 10, 10, 0.1, 0),
    shufflePatterns=TRUE, ...)

Arguments

x
a matrix with training inputs for the network
f2Units
controls the number of clusters assumed to be present
maxit
maximum of iterations to learn
initFunc
the initialization function to use
initFuncParams
the parameters for the initialization function
learnFunc
the learning function to use
learnFuncParams
the parameters for the learning function
updateFunc
the update function to use
updateFuncParams
the parameters for the update function
shufflePatterns
should the patterns be shuffled?
...
additional function parameters (currently not used)

Value

  • art2.default: an rsnns object. The fitted.values member contains the activation patterns for all inputs.

Details

art2: Art2 is very similar to art1, but for real-valued input. See art1 for more information. A difference is, that the art2 implementation doesn't assume two-dimensional input and output.

See Also

art2

Examples

Run this code
demo(art2_tetra)
demo(art2_tetraSnnsR)

Run the code above in your browser using DataLab