Learn R Programming

RSNNS (version 0.3-1)

confusionMatrix: Computes a confusion matrix.

Description

Computes a confusion matrix.

Usage

confusionMatrix(targets, predictions)

Arguments

targets
the known, correct target values
predictions
the corresponding predictions of a method for the targets

Value

  • the confusion matrix

Details

If the class labels are not already encoded, they are encoded using encodeClassLabels (with default values). The confusion matrix shows how many times a pattern with the real class x was classified as class y. A perfect method should result in a diagonal matrix. All values not on the diagonal are errors of the method.