Learn R Programming

RSNNS (version 0.3-1)

elman: Create and train an elman network.

Description

Create and train an elman network.

Usage

elman(x, ...)
## S3 method for class 'default':
elman(x, y, size=c(5), maxit=100, initFunc="JE_Weights", initFuncParams=c(1,
    -1, 0.3, 1, 0.5), learnFunc="JE_BP", learnFuncParams=c(0.2),
    updateFunc="JE_Order", updateFuncParams=c(0), shufflePatterns=TRUE,
    linOut=TRUE, outContext=FALSE, inputsTest, targetsTest, ...)

Arguments

x
a matrix with training inputs for the network
y
the corresponding targets values
size
number of units in the hidden layer(s)
maxit
maximum of iterations to learn
initFunc
the initialization function to use
initFuncParams
the parameters for the initialization function
learnFunc
the learning function to use
learnFuncParams
the parameters for the learning function
updateFunc
the update function to use
updateFuncParams
the parameters for the update function
shufflePatterns
should the patterns be shuffled?
linOut
sets the activation function of the output units to linear or logistic
outContext
if TRUE, the context units are also output units (untested)
inputsTest
a matrix with inputs to test the network
targetsTest
the corresponding targets for the test input
...
additional function parameters (currently not used)

Value

  • elman.default: an rsnns object.

Details

elman: Elman networks are recurrent networks and very similar to jordan networks.

See Also

jordan

Examples

Run this code
demo(iris)
demo(laser)
demo(eight_elman)
demo(eight_elmanSnnsR)

Run the code above in your browser using DataLab