Learn R Programming

RSNNS (version 0.3-1)

outputColumns: Function to get the columns that are targets.

Description

Function to get the columns that are targets.

Usage

outputColumns(patterns)

Arguments

patterns
matrix or data.frame containing the patterns

Details

This function extracts all columns from a matrix whose column names begin with "out". The example data of this package follows this naming convention.