Learn R Programming

RSNNS (version 0.3-1)

rbf: Create and train a radial basis function (rbf) network.

Description

Create and train a radial basis function (rbf) network.

Usage

rbf(x, ...)
## S3 method for class 'default':
rbf(x, y, size=c(5), maxit=100, initFunc="RBF_Weights", initFuncParams=c(0,
    1, 0, 0.02, 0.04), learnFunc="RadialBasisLearning",
    learnFuncParams=c(1e-05, 0, 1e-05, 0.1, 0.8),
    updateFunc="Topological_Order", updateFuncParams=c(0),
    shufflePatterns=TRUE, linOut=TRUE, inputsTest, targetsTest, ...)

Arguments

x
a matrix with training inputs for the network
y
the corresponding targets values
size
number of units in the hidden layer(s)
maxit
maximum of iterations to learn
initFunc
the initialization function to use
initFuncParams
the parameters for the initialization function
learnFunc
the learning function to use
learnFuncParams
the parameters for the learning function
updateFunc
the update function to use
updateFuncParams
the parameters for the update function
shufflePatterns
should the patterns be shuffled?
linOut
sets the activation function of the output units to linear or logistic
inputsTest
a matrix with inputs to test the network
targetsTest
the corresponding targets for the test input
...
additional function parameters (currently not used)

Value

  • rbf.default: an rsnns object.

Details

rbf: The use of an rbf-network is similar to that of an mlp. However, its initialization can be difficult and require prior knowledge. Before use of this function, you might want to read pp 172-183 of the SNNS User Manual 4.2. The initialization is performed in the current implementation by a call to RBF_Weights_Kohonen(0,0,0,0,0) and a successive call to the given initFunc (usually RBF_Weights). If this initialization doesn't fit your needs, you should use the RSNNS low-level interface to implement your own one. Have a look then at the demos/examples. Also, we note that depending on whether linear or logistic output is chosen, the initialization parameters have to be different (normally c(0,1,...) for linear and c(-4,4,...) for logistic output).

Examples

Run this code
demo(rbf_irisSnnsR)
demo(rbf_sin)
demo(rbf_sinSnnsR)

Run the code above in your browser using DataLab