Learn R Programming

RSNNS (version 0.3-1)

rbfDDA: Create and train a rbf network with the DDA algorithm.

Description

Create and train a rbf network with the DDA algorithm.

Usage

rbfDDA(x, ...)
## S3 method for class 'default':
rbfDDA(x, y, maxit=1, initFunc="Randomize_Weights", initFuncParams=c(-0.3,
    0.3), learnFunc="RBF-DDA", learnFuncParams=c(0.4, 0.2, 5),
    updateFunc="Topological_Order", updateFuncParams=c(0),
    shufflePatterns=TRUE, linOut=FALSE, ...)

Arguments

x
a matrix with training inputs for the network
y
the corresponding targets values
maxit
maximum of iterations to learn
initFunc
the initialization function to use
initFuncParams
the parameters for the initialization function
learnFunc
the learning function to use
learnFuncParams
the parameters for the learning function
updateFunc
the update function to use
updateFuncParams
the parameters for the update function
shufflePatterns
should the patterns be shuffled?
linOut
sets the activation function of the output units to linear or logistic
...
additional function parameters (currently not used)

Value

  • rbfDDA.default: an rsnns object.

Details

rbfDDA: As the output is winner-takes-all, this type of net can only be used for classification.

Examples

Run this code
demo(iris)
demo(rbfDDA_spiralsSnnsR)

Run the code above in your browser using DataLab