Learn R Programming

RSNNS (version 0.3-1)

summary.rsnns: Generic summary function for rsnns objects.

Description

Generic summary function for rsnns objects.

Usage

## S3 method for class 'rsnns':
summary(object, ...)

Arguments

object
the rsnns object
...
additional function parameters (currently not used)

Value

  • the contents of the .net file that SNNS would generate from the object, as a string.

Details

Print out a summary of the network. The function calls the function saveNet of the SNNS kernel to save the net to a temporary file. Then, it reads this file in, displays its contents and deletes the temporary file.