art1(x, ...)
## S3 method for class 'default':
art1(x, dimX, dimY, nClusters=nrow(x), maxit=100, initFunc="ART1_Weights",
initFuncParams=c(1, 1), learnFunc="ART1", learnFuncParams=c(0.9, 0,
0), updateFunc="ART1_Stable", updateFuncParams=c(0),
shufflePatterns=TRUE, ...)art1.default: an rsnns object. The fitted.values member of the object contains a
list of two-dimensional activation patterns.art1: Adaptive resonance theory (art) networks are association networks. I.e. they
perform clustering by finding a prototype to the given input. So, input and output
are the same type of data. Art1 is for binary inputs only, if you have real-valued input, use
art2 instead. In its current implementation, the network
has two-dimensional input (and output). The matrix x contains all
(one dimensional) input patterns. Internally, every one of these patterns
is converted to a two-dimensional pattern using parameters dimX and dimY.
The parameter nClusters controls the amount of clusters that are assumed to
be present in the input patterns. A detailed description of the theory is available from the SNNS decumentation.art2demo(art1_letters)
demo(art1_lettersSnnsR)Run the code above in your browser using DataLab