confusionMatrix(targets, predictions)encodeClassLabels
(with default values). The confusion matrix shows how many times a pattern
with the real class x was classified as class y. A perfect method
should result in a diagonal matrix. All values not on the diagonal
are errors of the method.