Rdocumentation
powered by
Learn R Programming
RSNNS (version 0.3-1)
setSnnsRSeedValue: Set the seed value used in all SnnsR objects.
Description
Set the seed value used in all
SnnsR
objects.
Usage
setSnnsRSeedValue(seed)
Arguments
seed
the seed to use. If 0, a seed based on the system time is generated.
Details
Set the seed value that will be used in the constructor of every
SnnsCLib
object to set the seed of rand().