Rdocumentation
powered by
Learn R Programming
RSNNS (version 0.4-3)
setSnnsRSeedValue: Set the SnnsR seed value
Description
Set the seed value used in all
SnnsR
objects. The seed value is used in the constructor of every
SnnsCLib
object to set the seed of rand().
Usage
setSnnsRSeedValue(seed)
Arguments
seed
the seed to use. If 0, a seed based on the system time is generated.