som(x, ...)
## S3 method for class 'default':
som(x, mapX=16, mapY=16, maxit=100, initFuncParams=c(1, -1),
learnFuncParams=c(0.5, mapX/2, 0.8, 0.8, mapX),
updateFuncParams=c(0, 0, 1), shufflePatterns=TRUE,
calculateMap=TRUE, calculateActMaps=FALSE,
calculateSpanningTree=FALSE, saveWinnersPerPattern=FALSE, targets,
...)som.default: an rsnns object. Depending on which calculation flags are
switched on, the som generates some special members:actMaps are an intermediary result, from which all other results can be computed. This list can be very long,
so normally it won't be saved.targets parameter is given -- contains for each unit (rows) and each class
present in the targets (columns), the amount of patterns of the class where the unit has won. From the labeledUnits,
the labeledMap can be computed, e.g. by voting of the class labels for the final label of the unit.labeledUnits using decodeClassLabels.som: This function creates and trains a self-organizing map.
As the computation might be slow if many patterns are involved,
much of its output is made switchable (see comments on return values).demo(som_iris)
demo(som_cubeSnnsR)Run the code above in your browser using DataLab