additional function parameters (currently not used)
Value
the contents of the .net file that SNNS would generate from the object, as a string.
Details
Print out a summary of the network. The function calls the function saveNet of the SNNS kernel to
save the net to a temporary file. Then, it reads this file in, displays its contents and
deletes the temporary file.